Re: [Freeipa-devel] [PATCH] 0037 Do not display traceback to user

2013-06-24 Thread Petr Viktorin

On 06/20/2013 02:37 PM, Tomas Babej wrote:

On 06/17/2013 03:11 PM, Ana Krivokapic wrote:

Hello,

Logging tracebacks at the INFO level caused them to be displayed to user on the
command line. Change the log level to DEBUG, so that tracebacks are not visible
to user.

https://fedorahosted.org/freeipa/ticket/3704



___
Freeipa-devel mailing list
Freeipa-devel@redhat.com
https://www.redhat.com/mailman/listinfo/freeipa-devel


ACK

Tomas



Pushed to master, ipa-3-2.


--
PetrĀ³

___
Freeipa-devel mailing list
Freeipa-devel@redhat.com
https://www.redhat.com/mailman/listinfo/freeipa-devel


Re: [Freeipa-devel] [PATCH] 0037 Do not display traceback to user

2013-06-20 Thread Tomas Babej

On 06/17/2013 03:11 PM, Ana Krivokapic wrote:

Hello,

Logging tracebacks at the INFO level caused them to be displayed to user on the
command line. Change the log level to DEBUG, so that tracebacks are not visible
to user.

https://fedorahosted.org/freeipa/ticket/3704



___
Freeipa-devel mailing list
Freeipa-devel@redhat.com
https://www.redhat.com/mailman/listinfo/freeipa-devel


ACK

Tomas
___
Freeipa-devel mailing list
Freeipa-devel@redhat.com
https://www.redhat.com/mailman/listinfo/freeipa-devel

[Freeipa-devel] [PATCH] 0037 Do not display traceback to user

2013-06-17 Thread Ana Krivokapic
Hello,

Logging tracebacks at the INFO level caused them to be displayed to user on the
command line. Change the log level to DEBUG, so that tracebacks are not visible
to user.

https://fedorahosted.org/freeipa/ticket/3704

-- 
Regards,

Ana Krivokapic
Associate Software Engineer
FreeIPA team
Red Hat Inc.

From 6af7238a489311e5a4b6167b9278a9df81aacbf4 Mon Sep 17 00:00:00 2001
From: Ana Krivokapic akriv...@redhat.com
Date: Mon, 17 Jun 2013 15:04:50 +0200
Subject: [PATCH] Do not display traceback to user

Logging tracebacks at the INFO level caused them to be displayed to user on the
command line. Change the log level to DEBUG, so that tracebacks are not visible
to user.

https://fedorahosted.org/freeipa/ticket/3704
---
 ipaserver/install/installutils.py | 9 -
 1 file changed, 4 insertions(+), 5 deletions(-)

diff --git a/ipaserver/install/installutils.py b/ipaserver/install/installutils.py
index 830a78a8bb805b6902114b7c1b826f25f842a3a7..278240f1e50da1ce24330b5897f41928044c0587 100644
--- a/ipaserver/install/installutils.py
+++ b/ipaserver/install/installutils.py
@@ -618,14 +618,13 @@ def run_script(main_function, operation_name, log_file_name=None,
 root_logger.info('The %s command was successful',
 operation_name)
 else:
 # Log at the INFO level, which is not output to the console
 # (unless in debug/verbose mode), but is written to a logfile
 # if one is open.
 tb = sys.exc_info()[2]
-root_logger.info('\n'.join(traceback.format_tb(tb)))
-root_logger.info('The %s command failed, exception: %s: %s',
-operation_name, type(e).__name__, e)
-exception = e
+root_logger.debug('\n'.join(traceback.format_tb(tb)))
+root_logger.debug('The %s command failed, exception: %s: %s',
+  operation_name, type(e).__name__, e)
 if fail_message and not isinstance(e, SystemExit):
 print fail_message
 raise
@@ -618,14 +618,13 @@ def run_script(main_function, operation_name, log_file_name=None,
 operation_name)
 else:
-# Log at the INFO level, which is not output to the console
+# Log at the DEBUG level, which is not output to the console
 # (unless in debug/verbose mode), but is written to a logfile
 # if one is open.
-- 
1.8.1.4

___
Freeipa-devel mailing list
Freeipa-devel@redhat.com
https://www.redhat.com/mailman/listinfo/freeipa-devel